Clazz.declarePackage("javajs.api");
Clazz.declareInterface(javajs.api, "GenericZipTools");
;//5.0.1-v7 Tue May 20 13:40:34 CDT 2025
